@@ -1,10 +1,7 @@
 # parser default cfg
-stack = []
-role = []
-type = []
-topics = []
-stack_args = []
-region = jobs = pause = version = template = nowait = compact = dryrun = None
+stack = role = type = topics = stack_args = []
+region = jobs = pause = version = template = None
+nowait = compact = dryrun = answer_yes = None
 max_retry_ecs_service_running_count = 0
 timedelta = 300
 dashboard = 'OnChange'
